==> ukui-greeter_1.2.5.orig.tar.gz: ukui-greeter/ukui-greeter/translations/pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">autenticação falhou, reinicie após 2 segundos</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">senha de acesso</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">impressão digital</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">fingerevin</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">íris</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <source>CN</source>
        <translation type="obsolete">CN</translation>
    </message>
    <message>
        <source>EN</source>
        <translation type="obsolete">EN</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <source>failed to start session.</source>
        <translation>falhou ao iniciar a sessão.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">Entrar</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <source>Login</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>logged in</source>
        <translation>logado</translation>
    </message>
    <message>
        <source>login</source>
        <translation>entrar</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Senha: </translation>
    </message>
    <message>
        <source>login:</source>
        <translation>entrar:</translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">Senha incorreta, por favor introduza novamente</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">por favor selecione o tipo de autenticação</translation>
    </message>
    <message>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Janela principal</translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">Adeus. Você gostaria de…</translation>
    </message>
    <message>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation>Outros usuários estão atualmente conectados a este computador, desligar agora também fechará essas outras sessões.</translation>
    </message>
    <message>
        <source>suspend</source>
        <translation>suspender</translation>
    </message>
    <message>
        <source>hibernate</source>
        <translation>hibernar</translation>
    </message>
    <message>
        <source>restart</source>
        <translation>reiniciar</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation>desligar</translation>
    </message>
    <message>
        <source>Goodbye. Would you like to...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">selecione o ambiente de área de trabalho</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished"> (Padrão)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">logado</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <source>Guest Session</source>
        <translation>Sessão Convidada</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-greeter_3.0.1.orig.tar.gz: ukui-greeter/ukui-greeter/translations/pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">autenticação falhou, reinicie após 2 segundos</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">senha de acesso</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">impressão digital</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">fingerevin</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">íris</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <source>CN</source>
        <translation type="obsolete">CN</translation>
    </message>
    <message>
        <source>EN</source>
        <translation type="obsolete">EN</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <source>failed to start session.</source>
        <translation>falhou ao iniciar a sessão.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">Entrar</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <source>Login</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>logged in</source>
        <translation>logado</translation>
    </message>
    <message>
        <source>login</source>
        <translation>entrar</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Senha: </translation>
    </message>
    <message>
        <source>login:</source>
        <translation type="vanished">entrar:</translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">Senha incorreta, por favor introduza novamente</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">por favor selecione o tipo de autenticação</translation>
    </message>
    <message>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Janela principal</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>suspend</source>
        <translation type="obsolete">suspender</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="obsolete">reiniciar</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="obsolete">desligar</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">Adeus. Você gostaria de…</translation>
    </message>
    <message>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation type="vanished">Outros usuários estão atualmente conectados a este computador, desligar agora também fechará essas outras sessões.</translation>
    </message>
    <message>
        <source>suspend</source>
        <translation type="vanished">suspender</translation>
    </message>
    <message>
        <source>hibernate</source>
        <translation type="vanished">hibernar</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="vanished">reiniciar</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="vanished">desligar</translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">selecione o ambiente de área de trabalho</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished"> (Padrão)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">logado</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <source>Guest Session</source>
        <translation>Sessão Convidada</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
